@@ -50,10 +50,10 @@ fn test_moderate_render(){
         "<blockquote>Outer quote with some text.\n</blockquote><p>Non-quoted text\nMore non-quoted\n</p><blockquote>Quote with some other text</blockquote>"
         ),
         ("Don't -> quote",
-        "<p>Don't -> quote</p>"
+        "<p>Don't -&gt; quote</p>"
         ),
         ("Don't -> quote\n> Do Quote\nDon't quote this either",
-        "<p>Don't -> quote\n</p><blockquote>Do Quote\n</blockquote><p>Don't quote this either</p>"
+        "<p>Don't -&gt; quote\n</p><blockquote>Do Quote\n</blockquote><p>Don't quote this either</p>"
         ),
         ("Testing an inline link [Link title](http://google.com)",
         "<p>Testing an inline link <a href=\"http://google.com\">Link title</a></p>"
@@ -61,11 +61,46 @@ fn test_moderate_render(){
         ("Testing an inline link to a header id [Link title](#some-header)",
         "<p>Testing an inline link to a header id <a href=\"#some-header\">Link title</a></p>"
         ),
+        ("Testing some details <details>\n<summary markdown=\"span\">Summary text goes here</summary>\nSome text goes here\n</details>",
+        "<p>Testing some details <details>\n<summary>Summary text goes here</summary>\n\n<p>Some text goes here\n</p>\n</details></p>"
+        ),
+        ("Testing some nested details <details>\n<summary markdown=\"span\">Outer summary</summary>\nOuter text<details>\n<summary markdown=\"span\">Inner Summary</summary>\nInner text\n</details>\n</details>",
+        "<p>Testing some nested details <details>\n<summary>Outer summary</summary>\n\n<p>Outer text<details>\n<summary>Inner Summary</summary>\n\n<p>Inner text\n</p>\n</details>\n</p>\n</details></p>"
+        ),
     ]);
 
     for test in tests.iter(){
         let html = render(test.0);
-        // println!("lex: {:?}", lex(test.0));
+        if html != test.1 {
+            println!("Test failing\n{:?}\n{:?}", html, test.1);
+            for (c1, c2) in test.1.chars().zip(html.chars()) {
+                if c1 != c2 {
+                    println!("Difference in {:?} {:?}", c1, c2);
+                }
+            }
+        }
+        assert_eq!(html, test.1);
+    }
+}
+
+#[test]
+fn test_table_render() {
+    let mut tests = Vec::new();
+    tests.extend(vec![
+        ("| Syntax      | Description | Test Text     |\n| :---        |    :----:   |          ---: |\n| Header      | Title       | Here's this   |\n| Paragraph   | Text        | And more      |", 
+        "<table class=\"table table-bordered\">\n\t<thead>\n\t<tr>\n\t\t<th style=\"text-align: left\">Syntax</th>\t\t<th style=\"text-align: center\">Description</th>\t\t<th style=\"text-align: right\">Test Text</th>\t</tr>\n\t</thead>\n\t<tbody>\n\t<tr>\n\t\t<td style=\"text-align: left\">Header</td>\n\t\t<td style=\"text-align: center\">Title</td>\n\t\t<td style=\"text-align: right\">Here's this</td>\n\t</tr>\n\t<tr>\n\t\t<td style=\"text-align: left\">Paragraph</td>\n\t\t<td style=\"text-align: center\">Text</td>\n\t\t<td style=\"text-align: right\">And more</td>\n\t</tr>\n\t</tbody>\n</table>"),
+    ]);
+
+    for test in tests.iter(){
+        let html = render(test.0);
+        if html != test.1 {
+            println!("Test failing\n{:?}\n{:?}", html, test.1);
+            for (c1, c2) in test.1.chars().zip(html.chars()) {
+                if c1 != c2 {
+                    println!("Difference in {:?} {:?}", c1, c2);
+                }
+            }
+        }
         assert_eq!(html, test.1);
     }
 }
